pub enum CreateVirtualNodeError {
BadRequest(String),
Conflict(String),
Forbidden(String),
InternalServerError(String),
LimitExceeded(String),
NotFound(String),
ServiceUnavailable(String),
TooManyRequests(String),
}Expand description
Errors returned by CreateVirtualNode
Variants
BadRequest(String)
The request syntax was malformed. Check your request syntax and try again.
Conflict(String)
The request contains a client token that was used for a previous update resource call with different specifications. Try the request again with a new client token.
Forbidden(String)
You don't have permissions to perform this action.
InternalServerError(String)
The request processing has failed because of an unknown error, exception, or failure.
LimitExceeded(String)
You have exceeded a service limit for your account. For more information, see Service Limits in the AWS App Mesh User Guide.
NotFound(String)
The specified resource doesn't exist. Check your request syntax and try again.
The request has failed due to a temporary failure of the service.
TooManyRequests(String)
The maximum request rate permitted by the App Mesh APIs has been exceeded for your account. For best results, use an increasing or variable sleep interval between requests.
Implementations
Sourceimpl CreateVirtualNodeError
impl CreateVirtualNodeError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<CreateVirtualNodeError>